<?php
/**
 * Core Design Favorite Pages module for Joomla! 2.5
 * @author		Daniel Rataj, <info@greatjoomla.com>
 * @package		Joomla 
 * @subpackage	Content
 * @category	Module
 * @version		2.5.x.2.0.3
 * @copyright	Copyright (C) 2007 - 2012 Great Joomla!, http://www.greatjoomla.com
 * @license		http://www.gnu.org/copyleft/gpl.html GNU/GPL 3
 * 
 * This file is part of Great Joomla! extension.   
 * This extension is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This extension is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

// no direct access
defined('_JEXEC') or die;

class modCdFapaHelper
{
	/**
	 * Check if user is logged in
	 * 
	 * @return boolean	True if user is logged
	 */
    public static function isLoggedIn()
    {
        $user = JFactory::getUser();

        if ($user->get('guest')) return false;
        return true;
    }
    
    /**
     * Load JS
     * 
     * @param $params
     * @return void
     */
    public static function loadModuleApplication($params)
    {
    	jimport('joomla.enviroment.uri');
    	$live_path = JURI::base(true); // define live site
    	
        $fapa_dir = $live_path . '/modules/mod_cdfapa';
        $document = JFactory::getDocument();
        
        // script
        $document->addScript($fapa_dir . '/tmpl/js/jquery.cdfapa.js');
        
        // CSS style
        $document->addStyleSheet($fapa_dir . '/tmpl/css/mod_cdfapa.css');
        
	    // add CSS stylesheet for RTL languages
		if ($document->direction === 'rtl')
		{
			$document->addStyleSheet($fapa_dir . '/tmpl/css/mod_cdfapa_rtl.css');
		}
        
        $uitheme = $params->get('uitheme', 'ui-lightness');
		if ($uitheme == '-1') $uitheme = 'ui-lightness';
        
        // coreTip
        $document->addScript($fapa_dir . '/tmpl/coreTip/js/jquery.coreTip.js');
        $document->addStyleSheet($fapa_dir . '/tmpl/coreTip/css/jquery.coreTip.css');
        
		$script = "
<!--
if (typeof(jQuery) == 'function') {
	jQuery(document).ready(function($){
		if (typeof($.fn.cdfapa) == 'function') {
			$('.cdfapa').cdfapa({
				language : {
					MOD_CDFAPA_NO_FAP : '" . JText::_('MOD_CDFAPA_NO_FAP', true) . "',
					MOD_CDFAPA_ADD : '" . JText::_('MOD_CDFAPA_ADD', true) . "',
					MOD_CDFAPA_MAX_LENGTH : '" . JText::_('MOD_CDFAPA_MAX_LENGTH', true) . "',
					MOD_CDFAPA_CUSTOMTITLE : '" . JText::_('MOD_CDFAPA_CUSTOMTITLE', true) . "',
					MOD_CDFAPA_DESCRIPTION : '" . JText::_('MOD_CDFAPA_DESCRIPTION', true) . "',
					MOD_CDFAPA_EMPTYVALUE : '" . JText::_('MOD_CDFAPA_EMPTYVALUE', true) . "',
					MOD_CDFAPA_CANCEL : '" . JText::_('MOD_CDFAPA_CANCEL', true) . "',
					MOD_CDFAPA_SAVE : '" . JText::_('MOD_CDFAPA_SAVE', true) . "',
					MOD_CDFAPA_CONFIRM : '" . JText::_('MOD_CDFAPA_CONFIRM', true) . "'
    			},
    			settings : {
    				title_length : " . (int)$params->get('title_length', 100) . ",
					uitheme : '" . $uitheme . "',
					token : '" . JUtility::getToken() . "',
					actualPage : " . (modCdFapaHelper::pageExists() ? 1 : 0) . ",
					hideaddicon : " . (int) $params->get('hideaddicon', 0) . ",
					hidefapalinks : " . (int) $params->get('hidefapalinks', 0) . "
    			}
    		});
		}
	})
}
// -->
";
		$document->addScriptDeclaration($script);
    }
    
    /**
     * Get actual URL with index.php prefix (non-SEF)
     * 
     * @return string		URL
     */
    public static function getURL()
    {
    	jimport('joomla.enviroment.uri');
    	$url = JRequest::getUri();
    	return $url;
    }
    
    /**
     * Create a database table
     * 
     * @return boolean	True if table was created
     */    
    public static function createDatabase()
    {
    	$row = modCdFapaHelper::dbInstance();
    	
    	if (!$row->createDb())
    	{
    		JError::raiseError(500, $row->getError());
            return false;
    	}
    	return true;
    }
    
    /**
     * Get list
     * 
     * @param $params
     * @return array
     */
    public static function getFapList($params = null)
    {
        $lists = array();
        
        $row = modCdFapaHelper::dbInstance();
        if (!$rows = $row->loadData($params->get('order_by', 'id'), $params->get('order_dir', 'ASC'))) {
        	return $lists;
        }
        
        foreach ($rows as $key=>$row)
        {
        	$lists[$key] = new stdClass();
        	$lists[$key]->fap_id = (int)$row->id;
        	$lists[$key]->fap_uid = (int)$row->uid;
            $lists[$key]->fap_title = $row->title;
            $lists[$key]->fap_link = $row->link;
            $lists[$key]->fap_note = $row->note;
        }
        return $lists;
    }
	
	/**
	 * Check if URL is already bookmarked
	 * 
	 * @return integer
	 */
	public static function pageExists()
	{
		$get_url = modCdFapaHelper::getURL();
		
		$row = modCdFapaHelper::dbInstance();
        if ($id = $row->getExistLink($get_url))  return (int)$id;
        return 0;
	}
	
	/**
	 * Add item to DB table
	 * 
	 * @return string
	 */
    public static function addFapa()
    {
        // Check for request forgeries
        if (!JRequest::checkToken()) return '0|' . JText::_('MOD_CDFAPA_INVALID_TOKEN');
        
        $get_url = modCdFapaHelper::getURL();
		if (modCdFapaHelper::pageExists($get_url)) return '0|' . JText::_('MOD_CDFAPA_ALREADY_EXISTS');
		
		$data['title'] = JRequest::getString('fapatitle', '', 'post', 0);
        $data['note'] = JRequest::getString('fapadesc', '', 'post', 0);
		$data['link'] = $get_url;
		
		$row = modCdFapaHelper::dbInstance();
		if (!$row->bind($data)) return '0|' . $row->getError();
		if (!$row->store()) return '0|' . $row->getError();
		
        $my_last_id = $row->getmyLastId();
        
        $new_element = '1|';
        $new_element .= '<div class="fapa fapa_active" id="fapa_' . $my_last_id . '">';
        	$new_element .= '<span class="fapa_icon ui-icon ui-icon-star">&nbsp;</span>';
        	$new_element .= '<a class="fapa_tooltip" href="' . str_replace('&', '&amp;', $get_url) . '" title="' . htmlspecialchars($data['note']) . '">' . htmlspecialchars($data['title']) . '</a>';
        	$new_element .= '<span class="fapa_delete"><a href="#delete" title="' . JText::_('MOD_CDFAPA_TRASH') . '">x</a></span>';
		$new_element .= '</div>';
        
        return $new_element;
        
    }
    
    /**
     * Remove item
     * 
     * @return string
     */
    public static function deleteFapa()
    {   
        // Check for request forgeries
        if (!JRequest::checkToken()) return JText::_('MOD_CDFAPA_INVALID_TOKEN');

        $fapa_id = JRequest::getCmd('fapa_id', '', 'post');
		$fapa_id = explode('_', $fapa_id);
		$fapa_id = $fapa_id[1];
        
        $row = modCdFapaHelper::dbInstance();

        if (!$row->delete($fapa_id)) return JText::_('MOD_CDFAPA_UNABLE_TO_CONNECT');
        return '1';

    }
    
	/**
	 * Load DB instance
	 * 
	 * @return A database object
	 */
	public static function dbInstance()
	{
        JTable::addIncludePath(array(dirname(__FILE__) . DS . 'tables'));
		$row = JTable::getInstance('cdfapa');
		return $row;
	}
}
?>