/**
 * Core Design Favorite Pages module for Joomla! 2.5
 * @author		Daniel Rataj, <info@greatjoomla.com>
 * @package		Joomla 
 * @subpackage	Content
 * @category	Module
 * @version		2.5.x.2.0.3
 * @copyright	Copyright (C) 2007 - 2012 Great Joomla!, http://www.greatjoomla.com
 * @license		http://www.gnu.org/copyleft/gpl.html GNU/GPL 3
 * 
 * This file is part of Great Joomla! extension.   
 * This extension is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This extension is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

if (typeof(jQuery) == 'function') {
	
	(function($) {
		
		$.fn.coreTip = function(options) {

			// set defaults
			var defaults = {
				theme : 'light',
				sticky : false,
				titleContainer : 'title',
				animSpeed : 500,
				openDelay : 300,
				width : '220px',
				icon : '',
				center : false
			},
			opts = $.extend(defaults, options),
			tipTemplate =
			'<div class="coreTip" style="width: ' + opts.width + ';">' +
				'<div class="' + opts.theme + '">' +
					'<div class="content">' +
						(opts.sticky ? '<div class="sticky" />' : '') + 
					'</div>' +
					'<div class="bottom">' +
						'<span>&nbsp;</span>' +
					'</div>' +
				'</div>' +
			'</div>',
			coreTip = undefined,
			tText = '',
			tipCont = '';
			
			return this.each(function() {
				
				var $this = $(this);
				
				// added pointer cursor to "link" element
				if ($this.attr('href') !== '#') {
					$this.css('cursor', 'pointer');
				}
				
				// get title - from title element or custom
				if (opts.titleContainer === 'title') {
					tipCont = $this.attr('title');
				} else if (opts.titleContainer !== 'title') {
					tipCont = opts.titleContainer;
				}
				$this.attr('title', '');
				
				// prevent click event on link
				$this.click(function(e) {
					if ($(this).attr('href') === '#') {
						e.preventDefault();
					}
				}).hover(function(e) {
					
					if (opts.sticky && typeof(coreTip) !== 'undefined') return true;
					
					// Inject the markup for the tooltip into the page and
					// set the tooltip global to the current markup and then hide it.
					$('body').append(tipTemplate);
					coreTip = $('div.coreTip:last');
					
					// prepend tooltip inner text
					coreTip.find('.content').prepend(tipCont);
					
					// prepend icon
					if (opts.icon) {
						coreTip.find('.content').prepend('<span class="tooltip_icon tooltip_icon_' + opts.icon + '" />');
					}
					
					// show tooltip
					showTooltip($(this), e);
					
				}, function(e) {
					// tooltip is sticky and already opened
					if (opts.sticky) {
						if (!coreTip.is(':animated') && coreTip.is(':visible')) {
							return true;
						}
					}
					
					coreTip.stop(true, false);
					hideTooltip($(this), e);
					
					coreTip = undefined;
				});
				
				return $this;
			});
			
			/**
			 * Get element position
			 * 
			 * @param 	element
			 * @return 	array
			 */
			function tooltipPosition(element, event) {
				var yOffset = coreTip.innerHeight() + 2,
				xOffset = (coreTip.innerWidth() / 2) - (element.innerWidth() / 2),
				pos = element.offset(),
				nPos = pos;
				
				// Add the offsets to the tooltip position
				nPos.top = pos.top - yOffset;
				nPos.left = pos.left - xOffset;
				
				return nPos;
			}
			
			/**
			 * Hide and remove tooltip
			 * 
			 * @return	void
			 */
			function hideTooltip(element, event) {
				
				var mPos = tooltipPosition(element, event);
				
				// hide tooltip and remove
				 coreTip.animate({
						 'opacity' : 'hide',
						 'top' : mPos.top - 10
					 },
					 opts.animSpeed,
					 function() {
						 $(this).remove();
					 }
				);
			}
			
			/**
			 * Show tooltip
			 * 
			 * @param	object		element
			 * @return	void
			 */
			function showTooltip(element, event) {
				
				var mPos = tooltipPosition(element, event);
				
				coreTip.css({
					'top' : mPos.top - 10,
					'left' : mPos.left
				}).delay(opts.openDelay).animate({
					'opacity' : 'show',
					'top' : mPos.top
				}, opts.animSpeed, function() {
					// click to close, I'm sticky
					if (opts.sticky) {
						// Click event if sticky
						coreTip.find('.sticky').click(function() {
							hideTooltip(element, event);
							coreTip = undefined;
						});
					}
				});
			}
		};
		
	})(jQuery);
}