/**
 * Core Design Favorite Pages module for Joomla! 2.5
 * @author		Daniel Rataj, <info@greatjoomla.com>
 * @package		Joomla 
 * @subpackage	Content
 * @category	Module
 * @version		2.5.x.2.0.3
 * @copyright	Copyright (C) 2007 - 2012 Great Joomla!, http://www.greatjoomla.com
 * @license		http://www.gnu.org/copyleft/gpl.html GNU/GPL 3
 * 
 * This file is part of Great Joomla! extension.   
 * This extension is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This extension is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

if (typeof(jQuery) == 'function') {
	
	(function($) {
		
		$.fn.cdfapa = function(options) {
	
			// set defaults
			var defaults = {
					language : {
						MOD_CDFAPA_NO_FAP : "No Favorite Pages",
						MOD_CDFAPA_ADD : "Add this page to Favorites",
						MOD_CDFAPA_MAX_LENGTH : "Character limit exceeded! Limit:",
						MOD_CDFAPA_CUSTOMTITLE : "Custom title",
						MOD_CDFAPA_DESCRIPTION : "Description",
						MOD_CDFAPA_EMPTYVALUE : "Please fill in all required fields!",
						MOD_CDFAPA_CANCEL : "Cancel",
						MOD_CDFAPA_SAVE : "Save",
						MOD_CDFAPA_CONFIRM : "Really?"
					},
					settings : {
						title_length : 100,
						uitheme : 'ui-lightness',
						token : 0,
						actualPage : 0,
						hideaddicon : 0,
						hidefapalinks : 0
					}
			},
			$cdfapa = {},
			fapa_box = {},
			fapa_utils = {},
			fapa_dialog = {},
			isRTL = false,
			$PHP_JS = new PHP_JS(),
			opts = $.extend(defaults, options);
			
			return this.each(function() {
				$cdfapa = $(this),
				fapa_box = $('.fapa_box', $cdfapa),
				fapa_utils = $('.fapa_utils', $cdfapa),
				isRTL = (getLanguageDirection($('.fapa_box .fapa:first a', $cdfapa).text()) === 'rtl' ? true : false);

				insertEmpty();
				insertAdd();
				erasable();
				hoverable();
				tooltip();
			});
			
			/**
			 * Make favorites erasable
			 */
			function erasable() {
				$('.fapa .fapa_delete', fapa_box).each(function() {
					if (typeof $(this).data('events') !== 'undefined') {
						// unbind first
						$(this).unbind('click');
					}
					
					// register event
					$(this).click(function(e) {
							e.preventDefault();
							
							var prompt = confirm(lang('MOD_CDFAPA_CONFIRM'));
							if (!prompt) return false;
							
							deleteFapa($(this).closest('.fapa'));
							$(this).unbind('click');
						}
					);
					
				});
			};
			
			/**
			 * Make container hoverable
			 */
			function hoverable() {
				$('.fapa', fapa_box).hover(
					function(e) {
						$(this).addClass('fapa_hover');
					},
					function() {
						$(this).removeClass('fapa_hover');
					}
				);
			};
			
			/**
			 * Tooltip
			 */
			function tooltip(elem) {
				if (typeof (elem) == 'undefined') elem = $cdfapa;

				clean_coreTip();
				
				$('.fapa_tooltip', elem).each(function() {
					if ($(this).attr('title')) {
						$(this).coreTip();
					}
				});
			};
			
			/**
			 * Clean coreTip "leftovers"
			 */
			function clean_coreTip() {
				var coreTip = $('.coreTip', 'body');
				if (coreTip.length) coreTip.remove();
			};
			
			/**
			 * Wrapper dialog with related theme
			 */
			 function theme() {
				var wrapper = '<div class="' + getSettings('uitheme') + '"></div>';
				fapa_dialog.dialog('widget').wrap(wrapper);
				$('.ui-widget-overlay').wrap(wrapper); // if overlay
			};
			
			/**
			 * Destroy dialog
			 */
			function removeDialog() {
				fapa_dialog.dialog('widget').parent('.' + getSettings('uitheme') + '').remove();
				$('body > #fapa_dialog').remove(); // remove container
			};
			
			/**
			 * Add to favourite
			 */
			function add() {
				
				clean_coreTip();
				
				// prevent non-existing dialog
				if ($('#fapa_dialog').length) return false;
				
				dialog_w = 300;

				fapa_dialog = $('<div />', {
					id : 'fapa_dialog'
				});


				fapa_dialog.dialog({
					width: dialog_w,
					draggable: false,
					resizable: false, 
					stack: false,
					position : {
						of  : $('.fapa_add', $cdfapa)
					},
					buttons: {
						'cancel' : function() {
							$(this).dialog('close');
						},
						'save' : function() {
							
							var titleinput = $('input[name="fapatitle"]', $(this));
							var descinput = $('input[name="fapadesc"]', $(this));
							
							// get title
							if ($.trim(titleinput.val()) == '') {
								alert(lang('MOD_CDFAPA_EMPTYVALUE'));
								titleinput.focus();
								return false;;
							}
							
							var note = $.trim(descinput.val());
							
							if (!note) {
								note = '';
							} else {
								// title maxlength routine
								var title_length = getSettings('title_length');
								
								if (note.split('').length > title_length) {
									alert(lang('MOD_CDFAPA_MAX_LENGTH') + ' ' + title_length);
									descinput.focus();
									return false;
								}
							}
							
							$.ajax({
								type: 'POST',
								data: $('form[name="add_fapa"]', $(this)).serialize(),
								beforeSend: function() {
									loading();
									fapa_dialog.dialog('close');
								},
								success: function(msg) {
									var msg_text = '';
									
									if ($PHP_JS.strpos(msg, '0|') !== false) {
										msg_text = $PHP_JS.str_replace('0|', '', msg);
										alert(msg_text);
										return false;
									}
									
									msg_text = $PHP_JS.str_replace('1|', '', msg);
									
									if ($('span', fapa_box).hasClass('fav_no_notes')) {
										$('span', fapa_box).remove();
										fapa_box.append(msg_text);
									} else {
										fapa_box.append(msg_text);
									}
									
									opts.settings.actualPage = 1;
									
									insertEmpty();
									insertAdd();
									erasable();
									
									tooltip($('.fapa:last', fapa_box)); // make link "tooltiple"
								},
								complete: function() {
									loading();
								}
							});
						}
					},
					open: function() {
						theme();
						buttonTitles();
						
						fapa_dialog.prev('.ui-dialog-titlebar').hide();
						fapa_dialog.html($('div.dialog_form').html());
						
						// focus - waiting for IE browser
						var waitBeforeFocus = setTimeout(function() {
							fapa_dialog.find('input[name="fapatitle"]').focus();
						}, 100);
						
						// form submit action
						fapa_dialog.find('form[name="add_fapa"] input[type="text"]').keydown(function(e) {
							if (e.which === 13) {
								fapa_dialog.next('div.ui-dialog-buttonpane').find('button:eq(1)').click();
							}
						});
						
					},
					close: function() {
						removeDialog($(this));
						$('.fapa_add', fapa_utils).button('enable'); // re-enable button
					}
				});
			};
			
			/**
			 * Delete favorite page
			 * 
			 * @param elem_to_remove
			 */
			function deleteFapa(elem_to_remove) {
				$.ajax({
					type: 'POST',
					async: true,
					data: 'fapa=remove&fapa_id=' + elem_to_remove.attr('id') + '&' + getSettings('token') + '=1',
					beforeSend: function() { loading(); },
					success: function(msg) {
						if (msg != 1) {
							alert(msg);
							return false;
						}
						
						if (elem_to_remove.children('a').attr('href') === (window.location.pathname + window.location.search)) {
							opts.settings.actualPage = 0;
						}
						
						elem_to_remove.fadeOut('slow', function () {
							$(this).remove();
							insertEmpty();
							insertAdd();
						});
					},
					complete: function () { loading(); }
				});
			};
			
			/**
			 * Check if box is empty, return boolean
			 */
			function isEmpty() {
				if (fapa_box.children('div').length == 0) return true;
				return false;
			};
			
			/**
			 * Insert Add icon
			 */
			function insertAdd() {
				if (getSettings('hideaddicon')) return false;
				
				// remove first if already exists
				if ($('button.fapa_add', fapa_utils).length) {
					$('button.fapa_add', fapa_utils).remove();
				}
				
				var add_button = $('<button />', {
					'class' : 'fapa_tooltip fapa_add'
				}).button({
					label : lang('MOD_CDFAPA_ADD'),
					icons : {
						primary : 'ui-icon-star'
					},
					text : false
				}).click(function(e) {
					e.preventDefault();
					add();
					$(this).button('disable');
				});
				
				fapa_utils.append(add_button);
				
				if (getSettings('actualPage') && !isEmpty(fapa_box)) {
					add_button.button('disable');
				}
				
				tooltip(fapa_utils); // make tooltipable
			};
			
			/**
			 * Insert "No pages" messages if necessary
			 */
			function insertEmpty() {
				if (getSettings('hidefapalinks')) {
					fapa_box.remove();
					return false;
				}
				
				if (isEmpty(fapa_box)) {
					fapa_box.html('<span class="fav_no_notes">' + lang('MOD_CDFAPA_NO_FAP') + '</span>');
				}
				
				tooltip(fapa_utils); // make tooltipable
			};
			
			/**
			 * Check if add icon exists, return boolean
			 */
			function addIcon() {
				var icon = $('div', fapa_utils).hasClass('fapa_add');
				if (icon) return true;
				return false;
			};
			
			/**
			 * Loading...
			 */
			function loading(event) {
				var loading = '<span class="fapa_loading"></span>',
				is_loading = $('.fapa_loading', fapa_utils);
				
				if (is_loading.length) {
					is_loading.remove();
				} else {
					fapa_utils.append(loading);
				}
			};
			
			/**
			 * Display buttons routine
			 */
			function buttonTitles() {
				fapa_dialog.dialog('widget').children('.ui-dialog-buttonpane').find('button').each(function() {
					switch($(this).text()) {
						case 'cancel':
							$(this).button('option', {
								label : lang('MOD_CDFAPA_CANCEL'),
								icons : {
									primary : 'ui-icon-close'
								},
								text : false
							});
							break;
						case 'save':
							$(this).button('option', {
								label : lang('MOD_CDFAPA_SAVE'),
								icons : {
									primary : 'ui-icon-disk'
								},
								text : false
							}).blur();
							break;
						default:
							break;
					}
				});
			};
			
			/**
			 * Get language
			 * 
			 * @return string
			 */
			function lang(string, def) {
				var lang = eval('opts.language.' + string);
				if (typeof(lang) === 'string') return lang;
				return def || '';
			};
			
			/**
			 * Get settings
			 * 
			 * @return mixed
			 */
			function getSettings(param, def) {
				var output = eval('opts.settings.' + param);
				if (typeof(output) !== 'undefined') return output;
				return def || null;
			};
			
			/**
			 * Get language direction
			 * 
			 * @param		string
			 * @return		string
			 */
			function getLanguageDirection(string) {
				if(typeof(string)=='undefined')return'ltr';NOT_UNICODE_LETTER=/[^\u0041-\u005A\u0061-\u007A\u00AA\u00B5\u00BA\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u0523\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0621-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971\u0972\u097B-\u097F\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C33\u0C35-\u0C39\u0C3D\u0C58\u0C59\u0C60\u0C61\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D28\u0D2A-\u0D39\u0D3D\u0D60\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC\u0EDD\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8B\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10D0-\u10FA\u10FC\u1100-\u1159\u115F-\u11A2\u11A8-\u11F9\u1200-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F4\u1401-\u166C\u166F-\u1676\u1681-\u169A\u16A0-\u16EA\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u18A8\u18AA\u1900-\u191C\u1950-\u196D\u1970-\u1974\u1980-\u19A9\u19C1-\u19C7\u1A00-\u1A16\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u200F\u2071\u207F\u2090-\u2094\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2183\u2184\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2C6F\u2C71-\u2C7D\u2C80-\u2CE4\u2D00-\u2D25\u2D30-\u2D65\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2E2F\u3005\u3006\u3031-\u3035\u303B\u303C\u3041-\u3096\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31B7\u31F0-\u31FF\u3400\u4DB5\u4E00\u9FC3\uA000-\uA48C\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA65F\uA662-\uA66E\uA67F-\uA697\uA717-\uA71F\uA722-\uA788\uA78B\uA78C\uA7FB-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA90A-\uA925\uA930-\uA946\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAC00\uD7A3\uF900-\uFA2D\uFA30-\uFA6A\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]/g;UNICODE_RTL=/^[\u0590-\u05FF\u0600-\u06FF\u0750-\u077F\uFB50-\uFDFF\uFE70-\uFEFF\u200F]/;var text=string.replace(NOT_UNICODE_LETTER,"");if(text&&UNICODE_RTL.test(text)){return'rtl'}else{return'ltr'}
			};
		};
		
	})(jQuery);
}